@@ -115,10 +115,11 @@ class Data(object):
     # 这个函数不应该使用
 
     @staticmethod
-    def update(table, conditions, or_cond=None, params=None, is_commit=True, show_sql=False,base_id='default',show_manager_id=False):
+    def update(table, conditions, params=None, or_cond=None,is_commit=True, show_sql=False,base_id='default',show_manager_id=False):
         if show_manager_id is True:
             print('本次任务通过',base_id,'执行')
-        Data.Base_pool[base_id].update(table, conditions, params, or_cond, is_commit, show_sql) if base_id in Data.Base_pool else None
+        # print(params)
+        Data.Base_pool[base_id].update(table, conditions,or_cond, params,is_commit, show_sql) if base_id in Data.Base_pool else None
         return
 
     @staticmethod
